@@ -13,8 +13,7 @@ coefBase<- function(object, digits=3, d2logl=0) { ## {{{
   return(res)
 } ## }}}
 
-wald.test <- function(object,contrast,coef.null=NULL,
-		      Sigma=NULL,null=NULL)
+wald.test <- function(object,contrast,coef.null=NULL,Sigma=NULL,null=NULL)
 { ## {{{
   if (is.null(Sigma)) {
      if (class(object)=="cor") Sigma <- object$var.theta else Sigma <- object$var.gamma;
@@ -84,7 +83,6 @@ timetest<-function(object,digits=3,hyp.label="p-value H_0:constant effect",out=0
 }
 } ## }}}
 
-
 is.diag <- function(m)
 {
 p <- nrow(m)
@@ -115,6 +113,78 @@ if (index.type==FALSE)  {
 	  package="timereg")
 idclust <- matrix(clustud[[4]],antclust,maxclust)
 
-out <- list(maxclust=maxclust,antclust=antclust,idclust=idclust,cluster.size=cluster.size)
+out <- list(clusters=clusters,maxclust=maxclust,antclust=antclust,idclust=idclust,cluster.size=cluster.size)
 } ## }}}
 
+residualsTimereg <- function(object,data=data)
+{ ## {{{
+
+if (class(object)!="cox.aalen" & class(object)!="aalen") stop("Computes residuals for Aalen or Cox.aalen object") 
+else {
+ formula<-attr(object,"Formula");
+ beta.fixed <- attr(object,"beta.fixed")
+ if (is.null(beta.fixed)) beta.fixed <- 1; 
+ model <- class(object); 
+ ldata<-aalen.des(formula,data=data,model=model);
+ id <- attr(object,"id"); 
+ mclusters <- attr(object,"cluster")
+ X<-ldata$X; 
+ time<-ldata$time2; 
+ Z<-ldata$Z;  
+ status<-ldata$status;
+ time2 <- attr(object,"stop"); 
+ start <- attr(object,"start");
+ status <- attr(object,"status");
+ if (!is.null(attr(object,"max.time"))) status <- status*(time2< attr(object,"max.time")); 
+ antpers<-nrow(X);
+ if (is.null(Z)==TRUE) {npar<-TRUE; semi<-0;}  else { Z<-as.matrix(Z); npar<-FALSE; semi<-1;}
+ if (npar==TRUE) {Z<-matrix(0,antpers,1); pz<-1; fixed<-0;} else {fixed<-1;pz<-ncol(Z);}
+ px<-ncol(X);
+
+ if (sum(abs(start))>0) lefttrunk <- 1  else lefttrunk <- 0;  cumhazleft <- 0; 
+ nn <- nrow(object$cum) 
+
+ cum <- Cpred(object$cum,time2)[,-1]
+ cumhaz0 <- apply(cum*X,1,sum)
+ cumhazleft <- rep(0,antpers)
+ RR <- rep(1,antpers); 
+
+if (class(object)=="cox.aalen")
+{ ## {{{
+  RR <- exp(Z %*% object$gamma); 
+  cumhaz <- cumhaz0 * RR;
+  if (lefttrunk==1) {
+      cum <- Cpred(object$cum,start)[,-1]
+      cumhazleft <- apply(cum*X,1,sum)
+      cumhazleft <- cumhazleft * RR;
+  }
+} ## }}}
+
+if (class(object)=="aalen")
+{#{{{
+  if (npar==FALSE) { ## semi-parametric risk model
+      ex.haz <- (Z %*% object$gamma) ; 
+      cumhaz <- cumhaz0+ex.haz*time2
+     if (lefttrunk==1) {
+	 cum <- Cpred(object$cum,start)[,-1]
+	 cumhazleft <- apply(cum*X,1,sum)
+	 cumhazleft  <-  cumhazleft+ex.haz*start
+     }
+
+  } else {  ## Aalen model
+	  cumhaz <- cumhaz0
+          if (lefttrunk==1) {
+	     cum <- Cpred(object$cum,start)[,-1]
+	     cumhazleft <- apply(cum*X,1,sum)
+	     if (npar==TRUE) cumhazleft <-  cumhazleft
+	     ex.haz <- (Z %*% object$gamma) * time2 ; 
+          }
+
+  }
+} #}}}
+
+} 
+
+residuals <- status- cumhaz
+out <- list(residuals=c(residuals),status=c(status),cumhaz=c(cumhaz),cumhazleft=c(cumhazleft),RR=RR)
+} ## }}}
